@@ -27,12 +27,13 @@ from httplib import BadStatusLine
 from urllib2 import HTTPError
 
 class Feed2Twitter(object):
-    def __init__(self,  url, username, passwd, mode='title'):
+    def __init__(self,  url, username, passwd, mode='title', items = 5):
         self.mode = mode
-        self.url=url
-        self.username=username
-        self.passwd=passwd
-        self.twApi=twitter.Api(username=self.username, password=self.passwd)
+        self.url = url
+        self.items = items
+        self.username = username
+        self.passwd = passwd
+        self.twApi = twitter.Api(username=self.username, password=self.passwd)
         self.twApi.SetSource('feed2twitter')
         self.set_attr_headers()
         self.rss = readrss.parse(url)
@@ -72,13 +73,13 @@ class Feed2Twitter(object):
     def update(self):
         lastread = self.rss.getlastRead()
         if not lastread:
-            self.twitIt(reversed(self.rss.feed['items'][:5]))
+            self.twitIt(reversed(self.rss.feed['items'][:self.items]))
         else:
             try:
                 lista = [item for item in self.rss.feed['items'] if item['published_parsed'] > lastread]
             except:
                 lista = [item for item in self.rss.feed['items'] if item['updated_parsed'] > lastread]
-            self.twitIt(reversed(lista[:5]))
+            self.twitIt(reversed(lista[:self.items]))
 
 def update():
     opt = Options()
@@ -89,7 +90,6 @@ def update():
         foo_config = resource_string(__name__, '../docs/default.cfg.sample')
         print(foo_config)
         sys.exit(1)
-    configfile =os.path.expanduser('~/.feed2twitter/default.cfg')
     try:
         fd =  open(options.config_filename, 'r')
     except IOError:
@@ -102,6 +102,10 @@ def update():
     username = conf.get("global", "username").strip()
     password = conf.get("global", "password").strip()
     mode = conf.get("global","mode").strip()
+    try:
+        items = int(conf.get("global","items").strip())
+    except NoOptionError:
+        items = 5
     try:
         interval = parsetime(conf.get("global","interval").strip())
     except:
@@ -109,6 +113,6 @@ def update():
         sys.exit(1)
     print(interval)
     while True:
-        feed2tw = Feed2Twitter(url, username, password, mode)
+        feed2tw = Feed2Twitter(url, username, password, mode, items)
         feed2tw.update()
         time.sleep(interval)
